==> sife-0.0.0.tgz: package/styleguide/js/component.js <==
/* global $ */
$(function() {

	var hrefParts = window.location.href.split('?');
	var dataSource = 'standard.json';

	if (hrefParts[1].split('#').length === 2) {

		dataSource = hrefParts[1].split('#')[1];
		hrefParts[1] = hrefParts[1].split('#')[0];

	}

	var componentName = hrefParts[1].split('/')[1],
		componentNamespace = hrefParts[1].split('/')[0];

	if (!hrefParts[1]) {

		var select = '<select onchange="window.location.href=\'' + hrefParts['0'] + '?\'+this.value"><option>Choose what to render...</option>';

		for (var tplKey in window.Handlebars.partials) {
			select+='<option>' + tplKey + '</option>';
		}

		select+='</select>';
		document.body.innerHTML = select;

	}

	else {

		// first, load the data
		var jsonUrl = '../components/' + hrefParts[1] + '/data/' + dataSource;
		// and css
		var cssUrl = '../build/css/components/' + hrefParts[1] + '.css';
		var css = document.createElement('link');
		css.rel = 'stylesheet';
		css.type = 'text/css';
		css.href = cssUrl;
		document.getElementsByTagName("head")[0].appendChild(css);

		$.getJSON(jsonUrl)
			.always(function(resp, status) {

				if (status === 'error') {
					resp = {};// no data for this component
				}

				window.IFE = window.IFE || {};
				window.IFE.data = resp;

				// then render
				var html = window.Handlebars.partials[hrefParts[1]](resp);

				if (window.Handlebars.partials[hrefParts[1] + '-wrapper']) {
					html = window.Handlebars.partials[hrefParts[1] + '-wrapper']({component: html});
				}

				document.querySelector('#target').innerHTML = html;

			});


	}

});

==> sife-0.0.7.tgz: package/styleguide/js/component.js <==
/* global $ */
/*jshint browser:true*/
$(function() {

	String.prototype.toCamelCase = function() {
		return this.replace(/^([A-Z])|[\s-_](\w)/g, function(match, p1, p2, offset) {
			if (p2) return p2.toUpperCase();
			return p1.toLowerCase();
		});
	};

	var hrefParts = window.location.href.split('?');
	var dataSource = 'standard.json';

	if (hrefParts[1].split('#').length === 2) {

		dataSource = hrefParts[1].split('#')[1];
		hrefParts[1] = hrefParts[1].split('#')[0];

	}

	var componentName = hrefParts[1].split('/')[1],
		componentNamespace = hrefParts[1].split('/')[0];

	if (!hrefParts[1]) {

		var select = '<select onchange="window.location.href=\'' + hrefParts['0'] + '?\'+this.value"><option>Choose what to render...</option>';

		for (var tplKey in window.Handlebars.partials) {
			select+='<option>' + tplKey + '</option>';
		}

		select+='</select>';
		document.body.innerHTML = select;

	}

	else {

		// first, load the data
		var jsonUrl = '../components/' + hrefParts[1] + '/data/' + dataSource;
		// and css
		var cssUrl = '__output__/css/components/' + hrefParts[1] + '.css';
		var css = document.createElement('link');
		css.rel = 'stylesheet';
		css.type = 'text/css';
		css.href = cssUrl;
		document.getElementsByTagName("head")[0].appendChild(css);

		$.getJSON(jsonUrl)
			.always(function(resp, status) {

				if (status === 'error') {
					resp = {};// no data for this component
				}

				window.IFE = window.IFE || {};
				window.IFE.data = resp;

				// then render
				var html = window.Handlebars.partials[hrefParts[1]](resp);

				if (window.Handlebars.partials[hrefParts[1] + '-wrapper']) {
					html = window.Handlebars.partials[hrefParts[1] + '-wrapper']({component: html});
				}

				document.querySelector('#target').innerHTML = html;

				$.getScript('__output__/js/' + hrefParts[1] + '.js', function(){
					var scriptId = hrefParts[1].toCamelCase().split('/').join('_');
					if(window.SIFE && typeof window.SIFE[scriptId] === 'function'){
						window.SIFE[scriptId]($('#target'));
					}
				});

			});


	}

});
